   
import requests
import argparse
import sys
import os
import json
import base64
import subprocess
import socket
import time
def get_hardware_hash():
    try:
        result = subprocess.check_output("cat /etc/machine-id", shell=True).decode().strip()
        print(f"[INFO] Хеш оборудования получен: {result}")
        return result
    except Exception as e:
        print(f"[ERROR] Ошибка получения хеша оборудования: {e}", file=sys.stderr)
        sys.exit(1)

def check_server_availability(server_url):
    try:
        # Пытаемся получить IP-адрес сервера
        ip = socket.gethostbyname(server_url)
        print(f"[INFO] Сервер '{server_url}' доступен по IP: {ip}")
        return True
    except socket.error as e:
        print(f"[ERROR] Ошибка разрешения доменного имени сервера: {e}", file=sys.stderr)
        return False

def check_network_connection():
    try:
        # Попытка подключения к внешнему ресурсу для проверки наличия интернета
        requests.get("http://google.com", timeout=5)
        print("[INFO] Интернет-соединение установлено.")
        return True
    except requests.exceptions.RequestException as e:
        print(f"[ERROR] Ошибка подключения к интернету: {e}", file=sys.stderr)
        return False

def send_empty_post(url):
    try:
        # Отправляем POST-запрос без явного указания заголовков и без данных
        response = requests.post(url, timeout=10)
        response.raise_for_status()  # выбросит исключение, если код ответа не 2xx
        
        try:
            json_response = response.json()
            print("[INFO] Получен ответ от сервера (JSON):")
            print(json.dumps(json_response, indent=2, ensure_ascii=False))
        except ValueError:
            # Если тело ответа не в формате JSON
            print("[INFO] Получен ответ от сервера (текст):")
            print(response.text)
    except requests.exceptions.RequestException as e:
        print(f"[ERROR] Ошибка при выполнении запроса: {e}", file=sys.stderr)
        if e.response is not None:
            print("[DEBUG] Текст ответа сервера:", e.response.text, file=sys.stderr)

def check_server():
    server_url = "http://license.applite.ru/api/check"
    license_key = "7b633184-cb0f-4002-879a-3acbd41392ad"
    hardware_hash = get_hardware_hash()
    
    if not server_url or not license_key:
        print("[ERROR] Переменные окружения LICENSE_SERVER_URL и LICENSE_KEY должны быть заданы", file=sys.stderr)
        sys.exit(1)
    
    if not check_network_connection():
        print("[ERROR] Проверьте подключение к интернету.", file=sys.stderr)
        sys.exit(1)
    
    if not check_server_availability("license.applite.ru"):
        print("[ERROR] Сервер недоступен. Проверьте правильность URL и доступность сервера.", file=sys.stderr)
        sys.exit(1)
    
    if not send_empty_post("http://license.applite.ru/api/check"):
        print("[ERROR] Сервер не отвечает. Возможно, сервер перегружен или недоступен.", file=sys.stderr)
        
    
    headers = {"Content-Type": "application/json"}
    data = json.dumps({"lkey": license_key, "hardware": hardware_hash})
    print("[INFO] Отправляем POST-запрос на сервер с данными лицензии и хешем оборудования.")
    
    try:
        response = requests.post(server_url, headers=headers, data=data, timeout=5)
        response.raise_for_status()
        print("[INFO] POST-запрос успешно выполнен.")
        print(f"[DEBUG] Ответ сервера: {response.text}")  # Отладочный вывод

        try:
            body = response.json()
            if isinstance(body, dict) and 'secret' in body:
                msg_base64 = body['secret']
            elif isinstance(body, str):  # Если сервер вернул строку, считаем, что это base64
                msg_base64 = body.strip().strip('"')
            else:
                print("[ERROR] Неподдерживаемый формат ответа", file=sys.stderr)
                sys.exit(1)
        except json.JSONDecodeError:
            msg_base64 = response.text.strip().strip('"')

        try:
            msg = base64.b64decode(msg_base64)
            print("[INFO] Декодирование ответа из Base64 прошло успешно.")
        except Exception as e:
            print(f"[ERROR] Ошибка декодирования Base64: {e}", file=sys.stderr)
            sys.exit(1)
        
        with open("license_secret.bin", "wb") as file:
            file.write(msg)
        print("[INFO] Лицензия успешно получена и сохранена в файле 'license_secret.bin'.")
    except requests.exceptions.RequestException as e:
        print(f"[ERROR] Ошибка доступа: {e}", file=sys.stderr)
        sys.exit(1)
    except Exception as e:
        print(f"[ERROR] Ошибка обработки ответа: {e}", file=sys.stderr)
        sys.exit(1)

if __name__ == "__main__":
    check_server()
